@@ -60,14 +60,11 @@ import sys
 import subprocess
 import textwrap
 import math
-import time
-import datetime
-import dateparser
 import copy
 from operator import itemgetter
 import seqLister
 
-VERSION = "2.6.0"     # Semantic Versioning 2.0.0
+VERSION = "2.6.1"     # Semantic Versioning 2.0.0
 
 PROG_NAME = "lsseq"
 
@@ -1069,7 +1066,7 @@ def main() :
                 [output of /bin/ls minus image sequences]
                 [list of images sequences]
             '''),
-        usage="%(prog)s [OPTION]... [FILE]...")
+        usage="%(prog)s [-h | --help] [OPTION]... [FILE]...")
 
     p.add_argument("--version", action="version", version=VERSION)
 
@@ -1221,7 +1218,7 @@ def main() :
         up to (and including) or after (and including) the time specified. The --time argument \
         specifies which frame to use for the cutoff comparison. \
         The optional CC (century) defaults to the current century. \
-        The optional -hh (hours), mm (minutes) or ss (seconds) \
+        The optional '-hh' (hours), 'mm' (minutes) or 'ss' (seconds) \
         default to zero if not specified.",
         metavar=("TENSE", "[CC]YYMMDD[-hh[mm[ss]]]"))
     p.add_argument("--silent", "--quiet", action="store_true",
@@ -1334,6 +1331,9 @@ def main() :
                     file=sys.stderr, sep='')
             sys.exit(1)
 
+        import datetime
+        import dateparser
+
         # Process the cutoff time set.
         #
         tzName = datetime.datetime.now(datetime.timezone.utc).astimezone().tzname()
@@ -1350,6 +1350,7 @@ def main() :
                     file=sys.stderr, sep='')
             sys.exit(1)
 
+        import time
         args.cutoffTime[1] = int(time.mktime(timeData.timetuple())) # Epoch time
 
     # Now the meat and potatoes.
